@@ -37,7 +37,11 @@ task('clean', () => {
 });
 
 task('inline', () => {
-    return src('dist/index.html').pipe(inlineSource()).pipe(rename('inline.html')).pipe(dest('dist/'));
+    const options = {
+        compress: false,
+    };
+
+    return src('dist/index.html').pipe(inlineSource(options)).pipe(rename('inline.html')).pipe(dest('dist/'));
 });
 
 task(
