@@ -1,3 +1,6 @@
+if (process.env.NODE_ENV === 'development') {
+    require('preact/debug');
+}
 import 'whatwg-fetch';
 import { h, render } from 'preact';
 import { App } from './components/app';
